---
name: Bug report
about: Report an issue on the project
labels: "bug"
---

**Environment**

- **justx version**:
- **just version**:
- **Python version**:
- **Operating system** (e.g. Ubuntu 22.04, Windows 11):

**Describe the issue**

<!-- A clear and concise description of what the issue is. -->

**Minimal way to reproduce the issue**

<!-- A minimal way to reproduce the issue. -->

**Expected behavior**

<!-- A clear and concise description of what you expected to happen. -->

**Additional context**

<!-- If relevant, add any other context about the problem here. -->
